@@ -14,14 +14,19 @@
 # limitations under the License.
 #
 
+from .logger import setup_logger, get_logger, get_child
 from .common import CertificateRequest, CommonConnection, RevocationRequest, ZoneConfig, CertField, KeyType, \
-    CustomField, Authentication, SCOPE_CM, SCOPE_PM, SCOPE_SSH
+    CustomField, Authentication, SCOPE_CM, SCOPE_PM, SCOPE_SSH, CSR_ORIGIN_LOCAL, CSR_ORIGIN_PROVIDED, \
+    CSR_ORIGIN_SERVICE, CHAIN_OPTION_FIRST, CHAIN_OPTION_IGNORE, CHAIN_OPTION_LAST
 from .connection_cloud import CloudConnection
 from .connection_tpp import TPPConnection
 from .connection_tpp_token import TPPTokenConnection
 from .connection_fake import FakeConnection
 from .pem import Certificate
 from .ssh_utils import SSHCertRequest, SSHKeyPair, write_ssh_files
+from .tpp_utils import IssuerHint
+
+setup_logger()
 
 
 def Connection(url=None, token=None, user=None, password=None, fake=False, http_request_kwargs=None):
