@@ -37,7 +37,7 @@ from .errors import VenafiConnectionError, ServerUnexptedBehavior, BadData, Clie
 from .http import HTTPStatus
 from .policy import PolicySpecification
 from .ssh_utils import SSHCertRequest, SSHRetrieveResponse
-
+from .tpp_utils import IssuerHint
 
 MIME_JSON = "application/json"
 MIME_HTML = "text/html"
@@ -46,6 +46,12 @@ MIME_CSV = "text/csv"
 MIME_ANY = "*/*"
 LOCALHOST = "127.0.0.1"
 DEFAULT_TIMEOUT = 180
+CSR_ORIGIN_PROVIDED = "provided"
+CSR_ORIGIN_LOCAL = "local"
+CSR_ORIGIN_SERVICE = "service"
+CHAIN_OPTION_FIRST = "first"
+CHAIN_OPTION_LAST = "last"
+CHAIN_OPTION_IGNORE = "ignore"
 
 
 class CertField:
@@ -236,29 +242,12 @@ class RecommendedSettings:
 
 
 class CertificateRequest:
-    def __init__(self, cert_id=None,
-                 san_dns=None,
-                 email_addresses="",
-                 ip_addresses=None,
-                 user_principal_names=None,
-                 uniform_resource_identifiers=None,
-                 attributes=None,
-                 key_type=None,
-                 private_key=None,
-                 key_password=None,
-                 csr=None,
-                 friendly_name=None,
-                 common_name=None,
-                 thumbprint=None,
-                 organization=None,
-                 organizational_unit=None,
-                 country=None,
-                 province=None,
-                 locality=None,
-                 origin=None,
-                 custom_fields=None,
-                 timeout=DEFAULT_TIMEOUT
-                 ):
+    def __init__(self, cert_id=None, san_dns=None, email_addresses="", ip_addresses=None, user_principal_names=None,
+                 uniform_resource_identifiers=None, attributes=None, key_type=None, private_key=None, key_password=None,
+                 csr=None, friendly_name=None, common_name=None, thumbprint=None, organization=None,
+                 organizational_unit=None, country=None, province=None, locality=None, origin=None, custom_fields=None,
+                 timeout=DEFAULT_TIMEOUT, csr_origin=CSR_ORIGIN_LOCAL, include_private_key=False, validity_hours=None,
+                 issuer_hint=IssuerHint.DEFAULT):
         """
         :param str cert_id: Certificate request id. Generating by server.
         :param list[str] san_dns: Alternative names for SNI.
@@ -277,9 +266,13 @@ class CertificateRequest:
         :param str origin: application identifier
         :param list[CustomField] custom_fields: list of custom fields values to be added to the certificate.
         :param int timeout: Timeout for the certificate to be retrieved from server. Measured in seconds.
+        :param str csr_origin: The origin of the CSR, either user provided, locally generated or service generated.
+        :param bool include_private_key: Indicates if the private key should be returned by the server or not.
+        :param int validity_hours: time in hours before the certificate expires.
+        :param IssuerHint issuer_hint: Issuer of the certificate. Ignored when platform is not TPP.
         """
 
-        self.chain_option = "last"
+        self.chain_option = CHAIN_OPTION_LAST  # "last"
         self.san_dns = san_dns or []
         self.email_addresses = email_addresses
         self.ip_addresses = ip_addresses or []
@@ -302,10 +295,17 @@ class CertificateRequest:
         self.locality = locality
         # CSR should be last, because it checks subject to match with over parameters
         self.csr = csr
+        if self.csr:
+            self.csr_origin = CSR_ORIGIN_PROVIDED
+        else:
+            self.csr_origin = csr_origin
         self.origin = origin or "Venafi VCert-Python"
         self.custom_fields = custom_fields
         self.cert_guid = None
         self.timeout = timeout
+        self.include_private_key = include_private_key
+        self.validity_hours = validity_hours
+        self.issuer_hint = issuer_hint
 
     def __setattr__(self, key, value):
         if key == "key_password":
@@ -330,6 +330,7 @@ class CertificateRequest:
             else:
                 raise ClientBadData("invalid private key type %s" % type(value))
         elif key == "csr":
+            self.csr_origin = CSR_ORIGIN_PROVIDED
             if isinstance(value, binary_type):
                 value = value.decode()
             elif not (isinstance(value, string_types) or value is None):
@@ -356,7 +357,7 @@ class CertificateRequest:
         self.__dict__[key] = value
 
     def _gen_key(self):
-        if self.key_type == None:
+        if self.key_type is None:
             self.key_type = KeyType(KeyType.RSA, 2048)
         if self.key_type.key_type == KeyType.RSA:
             self.private_key = rsa.generate_private_key(
@@ -439,7 +440,7 @@ class CertificateRequest:
                     # string we'll convert it into a bytes object then insert our header. Otherwise, we'll just
                     # insert the header in the passed in bytes.
                     if isinstance(upn, str):
-                        bupn = bytes(upn,'utf-8')
+                        bupn = bytes(upn, 'utf-8')
                     else:
                         bupn = upn
                     values = [12,len(upn)]
